/* tutkakillallnotes.c
 *
 * Copyright 2002-2005 Vesa Halttunen
 *
 * This file is part of Tutka.
 *
 * Tutka is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Tutka is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Tutka; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <signal.h>
#include <unistd.h>
#include <glib.h>
#include "midi.h"
char *nullcheck_error_string = "%s() called with null %s\n";

int main(int argc, char *argv[])
{
  struct midi_interface *midi;
  int i, j;

  midi = midi_alloc(MIDI_OSS, "/dev/midi", NULL);
  midi_interface_open(midi, DIRECTION_OUT);
  
  for (i = 0; i < 16; i++)
    for (j = 0; j < 128; j++)
      midi_note_off(midi, i, j, 127);

  sleep(3);

  midi_free(midi);

  return 0;
}
